"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
// Defining a union type for supported column types
let Field;
(function (_Field) {
  function setProperties(obj, props) {
    const model = obj.constructor;
    const cm = model.columnMapping;
    Object.keys(cm).forEach(k => {
      const columnType = cm[k];
      if (props[k] !== undefined) {
        const val = Field.propertyToModelValue(columnType.type, props[k]);
        Field.setProperty(obj, k, val);
      } else if (columnType.default && Field.isFunction(columnType.default)) {
        const val = columnType.default();
        Field.setProperty(obj, k, val);
      } else {
        Field.setProperty(obj, k, null);
      }
    });
    return obj;
  }
  _Field.setProperties = setProperties;
  function setProperty(obj, key, value) {
    obj[key] = value;
  }
  _Field.setProperty = setProperty;
  function toDatabaseValue(columnMapping, resource) {
    resource = sanitize(columnMapping, resource);
    return Object.entries(resource).reduce((o, _ref) => {
      let [key, value] = _ref;
      // Check if the column is defined in the mapping
      if (columnMapping[key]) {
        // Access the column type and convert the value
        const columnType = columnMapping[key];
        const databaseValue = propertyToDatabaseValue(columnType.type, value);
        // Set the converted value on the output object
        setProperty(o, key, databaseValue);
      }
      return o;
    }, {});
  }
  _Field.toDatabaseValue = toDatabaseValue;
  function propertyToDatabaseValue(type, value) {
    switch (type) {
      case 'JSON':
        return JSON.stringify(value);
      case 'BOOLEAN':
        return value ? 1 : 0;
      // If the type is not specified, return the value as is
      default:
        return value;
    }
  }
  _Field.propertyToDatabaseValue = propertyToDatabaseValue;
  function toModelValue(columnMapping, obj) {
    return Object.entries(columnMapping).reduce((o, _ref2) => {
      let [key, value] = _ref2;
      // Check if the property exists in the input object and if the type is defined
      if (obj.hasOwnProperty(key) && value.type) {
        // Access the column type and convert the value
        const modelValue = propertyToModelValue(value.type, obj[key]);
        // Set the converted value on the output object
        setProperty(o, key, modelValue);
      }
      return o;
    }, {});
  }
  _Field.toModelValue = toModelValue;
  function propertyToModelValue(type, value) {
    var _value$toString;
    switch (type) {
      case 'JSON':
        // Parse JSON if it's a string, otherwise return the value as is
        return typeof value === 'string' && JSON.parse(value ?? null) || value;
      case 'BOOLEAN':
        // Convert the value to a boolean
        return Boolean(value);
      case 'INTEGER':
      case 'FLOAT':
      case 'NUMERIC':
        // Convert numeric values to numbers, handling null or undefined cases
        return value !== null && value !== void 0 && (_value$toString = value.toString()) !== null && _value$toString !== void 0 && _value$toString.length ? Number(value) : null;
      // If the type is not specified, return the value as is
      default:
        return value;
    }
  }
  _Field.propertyToModelValue = propertyToModelValue;
  const isFunction = _Field.isFunction = p => Object.prototype.toString.call(p) === '[object Function]';
  function sanitize(columnMapping, obj) {
    const allowedKeys = Object.keys(columnMapping);
    return Object.keys(obj).reduce((ret, key) => {
      return allowedKeys.includes(key) ? {
        ...ret,
        [key]: obj[key]
      } : ret;
    }, {});
  }
  _Field.sanitize = sanitize;
})(Field || (Field = {})); // Exporting the functions as a module
var _default = exports.default = Field;
//# sourceMappingURL=Field.js.map