// TODO: add JSON BLOB support
export const customTypes = {
  JSON: 'TEXT'
};

// Defining a type for column configurations

/**
 *  id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT, name TEXT, age INTEGER
 */
export function createTableColumns(columnMapping) {
  return Object.entries(columnMapping).map(_ref => {
    let [columnName, column] = _ref;
    const {
      type,
      not_null,
      primary_key,
      unique,
      foreign_key
    } = column;
    const typeString = customTypes[type] || type;
    const constraints = [];
    if (not_null) constraints.push('NOT NULL');
    if (primary_key) constraints.push('PRIMARY KEY AUTOINCREMENT');
    if (unique) constraints.push('UNIQUE');
    if (foreign_key) {
      const {
        table,
        key
      } = foreign_key;
      constraints.push(`FOREIGN KEY (${columnName}) REFERENCES ${table}(${key})`);
    }
    return `${columnName} ${typeString} ${constraints.join(' ')}`.trim();
  }).join(', ');
}
//# sourceMappingURL=ColumnType.js.map