import type { Type } from "./Field";

// TODO: add JSON BLOB support
export const customTypes: Record<string, string> = { JSON: 'TEXT' };

// Defining a type for column configurations
export type ColumnType = {
  type: Type;
  primary_key?: boolean;
  foreign_key?: ForeignKey;
  not_null?: boolean;
  unique?: boolean;
  default?: () => any;
};

export type ForeignKey = {
  table: string;
  key: string;
}

/**
 *  id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT, name TEXT, age INTEGER
 */
export function createTableColumns(columnMapping: { [s: string]: ColumnType }): string {
  return Object.entries(columnMapping)
    .map(([columnName, column]) => {
      const { type, not_null, primary_key, unique, foreign_key } = column;
      const typeString = customTypes[type] || type;
      const constraints = [];

      if (not_null) constraints.push('NOT NULL');
      if (primary_key) constraints.push('PRIMARY KEY AUTOINCREMENT');
      if (unique) constraints.push('UNIQUE');
      if (foreign_key) {
        const { table, key } = foreign_key;
        constraints.push(`FOREIGN KEY (${columnName}) REFERENCES ${table}(${key})`);
      }

      return `${columnName} ${typeString} ${constraints.join(' ')}`.trim();
    })
    .join(', ');
}